@@ -445,7 +445,8 @@ save_camera_file_to_file (
 		unlink(s);
 		if (-1 == rename (curname, s)) {
 			/* happens if the user specified a absolute path with --filename */
-			if (errno == EXDEV) {
+			/* EPERM happens on windows, see https://github.com/gphoto/libgphoto2/issues/97 */
+			if ((errno == EXDEV) || (errno == EPERM)) {
 				char buf[8192];
 				int in_fd, out_fd;
 
@@ -1037,6 +1038,8 @@ capture_generic (CameraCaptureType type, const char __unused__ *name, int downlo
 					(result == GP_ERROR_CANCEL)		||
 					(result == GP_ERROR_NO_SPACE)		||
 					(result == GP_ERROR_IO_USB_CLAIM)	||
+					(result == GP_ERROR_IO_LOCK)		||
+					(result == GP_ERROR_CAMERA_BUSY)	||
 					(result == GP_ERROR_OS_FAILURE)
 				)
 					return (result);
@@ -1101,7 +1104,7 @@ capture_generic (CameraCaptureType type, const char __unused__ *name, int downlo
 				 */
 				do {
 					next_pic_time.tv_sec += glob_interval;
-				} while (timediff_now (&next_pic_time) < 0);
+				} while (glob_interval && (timediff_now (&next_pic_time) < 0));
 			}
 			capture_now = 0;
 		} else {
